==> advert-gp-2.0.0-sources.jar: com/yodo1/advert/factory/Yodo1AdvertProvider.java <==
package com.yodo1.advert.factory;

import android.app.Application;
import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.yodo1.advert.AdapterAdvertBase;
import com.yodo1.advert.entity.AdvertType;
import com.yodo1.onlineconfig.Yodo1OnlineConfig;
import com.yodo1.sdk.kit.SysUtils;
import com.yodo1.sdk.kit.YFileUtils;
import com.yodo1.sdk.kit.YLog;

import java.util.Map;

/**
 * @author zhuxc
 */
public class Yodo1AdvertProvider extends ContentProvider {


    @Override
    public boolean onCreate() {

        String str = YFileUtils.readFilesFromSDCard(".yodo1ads");
        if (!TextUtils.isEmpty(str) && str.contains("openYodo1Log")){
            YLog.setDebugMode(true);
            YLog.setOnLog(true);
            YLog.v("Yodo1AdvertHelper 开启Yodo1Log，打开测试模式");
        }

        String processName = SysUtils.getProcessName((Application) getContext(), android.os.Process.myPid());
        if(((Application) getContext()).getPackageName().equals(processName)) { //判断是否为当前主进程，以防有多进程造成重复初始化
            if (Yodo1OnlineConfig.getInstance().hasData()) {
                Yodo1AdvertAdapterFactory.getInstance().initAdvertAdapters((Application) getContext());

                for (AdvertType type : AdvertType.values()) {
                    for (Map.Entry<String, AdapterAdvertBase> adapter : Yodo1AdvertAdapterFactory.getInstance().getAdapters(type).entrySet()) {
                        if (adapter.getValue() != null) {
                            adapter.getValue().onCreateApplication((Application) getContext());
                        }
                    }
                }

            }
        }


        return true;
    }

    @Nullable
    @Override
    public Cursor query(@NonNull Uri uri, @Nullable String[] strings, @Nullable String s, @Nullable String[] strings1, @Nullable String s1) {
        return null;
    }

    @Nullable
    @Override
    public String getType(@NonNull Uri uri) {
        return null;
    }


    @Override
    public Uri insert(@NonNull Uri uri, @Nullable ContentValues contentValues) {
        return null;
    }

    @Override
    public int delete(@NonNull Uri uri, @Nullable String s, @Nullable String[] strings) {
        return 0;
    }

    @Override
    public int update(@NonNull Uri uri, @Nullable ContentValues contentValues, @Nullable String s, @Nullable String[] strings) {
        return 0;
    }
}

==> advert-gp-3.0.1-sources.jar: com/yodo1/advert/factory/Yodo1AdvertProvider.java <==
package com.yodo1.advert.factory;

import android.app.Application;
import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.yodo1.advert.AdapterAdvertBase;
import com.yodo1.advert.entity.AdvertType;
import com.yodo1.advert.helper.Yodo1AdvertHelper;
import com.yodo1.onlineconfig.Yodo1OnlineConfig;
import com.yodo1.sdk.kit.SysUtils;
import com.yodo1.sdk.kit.YFileUtils;
import com.yodo1.sdk.kit.YLog;

import java.util.Map;

/**
 * @author zhuxc
 */
public class Yodo1AdvertProvider extends ContentProvider {

    private ActivityObserver lifecycle;
    @Override
    public boolean onCreate() {

        String str = YFileUtils.readFilesFromSDCard(".yodo1ads");
        if (!TextUtils.isEmpty(str) && str.contains("openYodo1Log")){
            YLog.setDebugMode(true);
            YLog.setOnLog(true);
            YLog.v("Yodo1AdvertHelper 开启Yodo1Log，打开测试模式");
        }

        registerLifecycle((Application) getContext());

        String processName = SysUtils.getProcessName((Application) getContext(), android.os.Process.myPid());
        if(((Application) getContext()).getPackageName().equals(processName)) { //判断是否为当前主进程，以防有多进程造成重复初始化
            if (Yodo1OnlineConfig.getInstance().hasData()) {

                //加载广告插件
                Yodo1AdvertAdapterFactory.getInstance().initAdvertAdapters((Application) getContext());
                //广告Application初始化
                for (Map.Entry<String, AdapterAdvertBase> adapter : Yodo1AdvertAdapterFactory.getInstance().getAdapters().entrySet()) {
                    if (adapter.getValue() != null) {
                        adapter.getValue().onCreateApplication((Application) getContext());
                    }
                }
                Yodo1AdvertHelper.getInstance().onCreateApplication(getContext());
            }
        }


        return true;
    }

    private void registerLifecycle(Application context) {
        if (null != lifecycle) {
            context.unregisterActivityLifecycleCallbacks(lifecycle);
        }
        lifecycle = new ActivityObserver();
        context.registerActivityLifecycleCallbacks(lifecycle);
    }


    @Nullable
    @Override
    public Cursor query(@NonNull Uri uri, @Nullable String[] strings, @Nullable String s, @Nullable String[] strings1, @Nullable String s1) {
        return null;
    }

    @Nullable
    @Override
    public String getType(@NonNull Uri uri) {
        return null;
    }


    @Override
    public Uri insert(@NonNull Uri uri, @Nullable ContentValues contentValues) {
        return null;
    }

    @Override
    public int delete(@NonNull Uri uri, @Nullable String s, @Nullable String[] strings) {
        return 0;
    }

    @Override
    public int update(@NonNull Uri uri, @Nullable ContentValues contentValues, @Nullable String s, @Nullable String[] strings) {
        return 0;
    }
}
